@@ -1,4 +1,6 @@
 // THIS FILE IS GENERATED. ONE SHOULD NOT MODIFY IT
+#![cfg_attr(docsrs, feature(doc_cfg))]
+#![cfg_attr(docsrs, doc(cfg(feature = "ns-cert")))]
 //! This module provides terms for `The Cert Ontology 1.0` vocabulary
 //!
 //! ## Vocabulary:
@@ -7,9 +9,9 @@
 //! |-----|-----|
 //! |**Title**|The Cert Ontology 1.0|
 //! |**Prefix**|cert|
-//! |**Namespace base IRI**|[https://www.w3.org/ns/auth/cert#](https://www.w3.org/ns/auth/cert#)|
+//! |**Namespace base IRI**|<https://www.w3.org/ns/auth/cert#>|
 //! |**Description**|Ontology for Certificates and crypto stuff.|
-//! |**Is defined by**|[http://www.w3.org/ns/auth/cert.rdf](http://www.w3.org/ns/auth/cert.rdf)|
+//! |**Is defined by**|<http://www.w3.org/ns/auth/cert.rdf>|
 //!
 
 use crate::namespace;
