@@ -1,4 +1,6 @@
 // THIS FILE IS GENERATED. ONE SHOULD NOT MODIFY IT
+#![cfg_attr(docsrs, feature(doc_cfg))]
+#![cfg_attr(docsrs, doc(cfg(feature = "ns-dcam")))]
 //! This module provides terms for `Metadata terms for vocabulary description` vocabulary
 //!
 //! ## Vocabulary:
@@ -7,9 +9,9 @@
 //! |-----|-----|
 //! |**Title**|Metadata terms for vocabulary description|
 //! |**Prefix**|dcam|
-//! |**Namespace base IRI**|[http://purl.org/dc/dcam/](http://purl.org/dc/dcam/)|
+//! |**Namespace base IRI**|<http://purl.org/dc/dcam/>|
 //! |**Description**||
-//! |**Is defined by**|[http://purl.org/dc/dcam/](http://purl.org/dc/dcam/)|
+//! |**Is defined by**|<http://purl.org/dc/dcam/>|
 //!
 
 use crate::namespace;
