@@ -1,4 +1,6 @@
 // THIS FILE IS GENERATED. ONE SHOULD NOT MODIFY IT
+#![cfg_attr(docsrs, feature(doc_cfg))]
+#![cfg_attr(docsrs, doc(cfg(feature = "ns-dpv")))]
 //! This module provides terms for `dpv` vocabulary
 //!
 //! ## Vocabulary:
@@ -7,9 +9,9 @@
 //! |-----|-----|
 //! |**Title**||
 //! |**Prefix**|dpv|
-//! |**Namespace base IRI**|[http://www.w3.org/ns/dpv#](http://www.w3.org/ns/dpv#)|
+//! |**Namespace base IRI**|<http://www.w3.org/ns/dpv#>|
 //! |**Description**||
-//! |**Is defined by**|[https://dpvcg.github.io/dpv/dpv.jsonld](https://dpvcg.github.io/dpv/dpv.jsonld)|
+//! |**Is defined by**|<https://dpvcg.github.io/dpv/dpv.jsonld>|
 //!
 
 use crate::namespace;
