@@ -1,4 +1,6 @@
 // THIS FILE IS GENERATED. ONE SHOULD NOT MODIFY IT
+#![cfg_attr(docsrs, feature(doc_cfg))]
+#![cfg_attr(docsrs, doc(cfg(feature = "ns-sh")))]
 //! This module provides terms for `W3C Shapes Constraint Language (SHACL) Vocabulary` vocabulary
 //!
 //! ## Vocabulary:
@@ -7,9 +9,9 @@
 //! |-----|-----|
 //! |**Title**|W3C Shapes Constraint Language (SHACL) Vocabulary|
 //! |**Prefix**|sh|
-//! |**Namespace base IRI**|[http://www.w3.org/ns/shacl#](http://www.w3.org/ns/shacl#)|
+//! |**Namespace base IRI**|<http://www.w3.org/ns/shacl#>|
 //! |**Description**|This vocabulary defines terms used in SHACL, the W3C Shapes Constraint Language.|
-//! |**Is defined by**|[http://www.w3.org/ns/shacl#](http://www.w3.org/ns/shacl#)|
+//! |**Is defined by**|<http://www.w3.org/ns/shacl#>|
 //!
 
 use crate::namespace;
