@@ -1,4 +1,6 @@
 // THIS FILE IS GENERATED. ONE SHOULD NOT MODIFY IT
+#![cfg_attr(docsrs, feature(doc_cfg))]
+#![cfg_attr(docsrs, doc(cfg(feature = "ns-vartrans")))]
 //! This module provides terms for `Lexicon Model for Ontologies - Vartrans` vocabulary
 //!
 //! ## Vocabulary:
@@ -7,9 +9,9 @@
 //! |-----|-----|
 //! |**Title**|Lexicon Model for Ontologies - Vartrans|
 //! |**Prefix**|vartrans|
-//! |**Namespace base IRI**|[https://www.w3.org/ns/lemon/vartrans#](https://www.w3.org/ns/lemon/vartrans#)|
+//! |**Namespace base IRI**|<https://www.w3.org/ns/lemon/vartrans#>|
 //! |**Description**|A model for the representation of lexical information relative to ontologies. Variation and translation module.|
-//! |**Is defined by**|[http://rdf.greggkellogg.net/distiller?command=serialize&output_format=ntriples&url=https:%2F%2Fwww.w3.org%2Fns%2Flemon%2Fvartrans&raw](http://rdf.greggkellogg.net/distiller?command=serialize&output_format=ntriples&url=https:%2F%2Fwww.w3.org%2Fns%2Flemon%2Fvartrans&raw)|
+//! |**Is defined by**|<http://rdf.greggkellogg.net/distiller?command=serialize&output_format=ntriples&url=https:%2F%2Fwww.w3.org%2Fns%2Flemon%2Fvartrans&raw>|
 //!
 
 use crate::namespace;
