@@ -1,4 +1,6 @@
 // THIS FILE IS GENERATED. ONE SHOULD NOT MODIFY IT
+#![cfg_attr(docsrs, feature(doc_cfg))]
+#![cfg_attr(docsrs, doc(cfg(feature = "ns-vs")))]
 //! This module provides terms for `SemWeb Vocab Status ontology` vocabulary
 //!
 //! ## Vocabulary:
@@ -7,9 +9,9 @@
 //! |-----|-----|
 //! |**Title**|SemWeb Vocab Status ontology|
 //! |**Prefix**|vs|
-//! |**Namespace base IRI**|[http://www.w3.org/2003/06/sw-vocab-status/ns#](http://www.w3.org/2003/06/sw-vocab-status/ns#)|
+//! |**Namespace base IRI**|<http://www.w3.org/2003/06/sw-vocab-status/ns#>|
 //! |**Description**|An RDF vocabulary for relating SW vocabulary terms to their status.|
-//! |**Is defined by**|[http://www.w3.org/2003/06/sw-vocab-status/ns#](http://www.w3.org/2003/06/sw-vocab-status/ns#)|
+//! |**Is defined by**|<http://www.w3.org/2003/06/sw-vocab-status/ns#>|
 //!
 
 use crate::namespace;
