@@ -1,4 +1,6 @@
 // THIS FILE IS GENERATED. ONE SHOULD NOT MODIFY IT
+#![cfg_attr(docsrs, feature(doc_cfg))]
+#![cfg_attr(docsrs, doc(cfg(feature = "ns-xsd")))]
 //! This module provides terms for `xsd` vocabulary
 //!
 //! ## Vocabulary:
@@ -7,9 +9,9 @@
 //! |-----|-----|
 //! |**Title**||
 //! |**Prefix**|xsd|
-//! |**Namespace base IRI**|[http://www.w3.org/2001/XMLSchema#](http://www.w3.org/2001/XMLSchema#)|
+//! |**Namespace base IRI**|<http://www.w3.org/2001/XMLSchema#>|
 //! |**Description**||
-//! |**Is defined by**|[https://raw.githubusercontent.com/ruby-rdf/rdf/master/etc/xsd.ttl](https://raw.githubusercontent.com/ruby-rdf/rdf/master/etc/xsd.ttl)|
+//! |**Is defined by**|<https://raw.githubusercontent.com/ruby-rdf/rdf/master/etc/xsd.ttl>|
 //!
 
 use crate::namespace;
